@@ -67,6 +67,8 @@ is_model <- function(x) {
       "flexsurvreg",
       "gam",
       "Gam",
+      "GAMBoost",
+      "gamlr",
       "gamlss",
       "gamm",
       "gamm4",
@@ -76,8 +78,17 @@ is_model <- function(x) {
       "geeglm",
       "glimML",
       "glm",
+      "glmaag",
+      "glmbb",
+      "glmboostLSS",
+      "glmc",
+      "glmdm",
+      "glmdisc",
       "glmerMod",
+      "glmlep",
       "glmmadmb",
+      "glmmEP",
+      "glmmfields",
       "glmmLasso",
       "glmmPQL",
       "glmmTMB",
@@ -104,6 +115,7 @@ is_model <- function(x) {
       "lqmm",
       "lrm",
       "manova",
+      "mboostLSS",
       "mclogit",
       "mmclogit",
       "mcmc",
@@ -127,14 +139,18 @@ is_model <- function(x) {
       "plmm",
       "polr",
       "psm",
+      "rdrobust",
       "ridgelm",
       "rjags",
       "rlm",
       "rlme",
       "rlmerMod",
+      "rma",
+      "rma.uni",
       "rms",
       "rq",
       "rqss",
+      "slm",
       "speedlm",
       "speedglm",
       "stanmvreg",
