@@ -12,9 +12,6 @@
 #' @return The number of observations used to fit the model, or \code{NULL} if
 #'   this information is not available.
 #'
-#' @note For model-objects supported by \pkg{insight} that \emph{do not} have
-#' a \code{nobs()}-method, \pkg{insight} provides a \code{nobs()}-method as well.
-#'
 #' @examples
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
@@ -33,12 +30,13 @@ n_obs.default <- function(x, ...) {
     class(x) <- c(class(x), c("glm", "lm"))
   }
 
-  tryCatch({
-    stats::nobs(x)
-  },
-  error = function(x) {
-    NULL
-  }
+  tryCatch(
+    {
+      stats::nobs(x)
+    },
+    error = function(x) {
+      NULL
+    }
   )
 }
 
@@ -63,13 +61,6 @@ n_obs.gamm <- function(x, ...) {
   NextMethod()
 }
 
-#' @export
-nobs.gamm <- function(object, ...) {
-  x <- object$gam
-  class(x) <- c(class(x), c("glm", "lm"))
-  n_obs(x, ...)
-}
-
 
 
 #' @export
@@ -77,11 +68,6 @@ n_obs.bayesx <- function(x, ...) {
   length(x$response)
 }
 
-#' @export
-nobs.bayesx <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -89,11 +75,6 @@ n_obs.flexsurvreg <- function(x, ...) {
   x$N
 }
 
-#' @export
-nobs.flexsurvreg <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -101,11 +82,6 @@ n_obs.bamlss <- function(x, ...) {
   nrow(x$model.frame)
 }
 
-#' @export
-nobs.bamlss <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -113,11 +89,6 @@ n_obs.lmRob <- function(x, ...) {
   length(x$fitted.values)
 }
 
-#' @export
-nobs.lmRob <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -126,16 +97,12 @@ n_obs.LORgee <- function(x, ...) {
 }
 
 
+
 #' @export
 n_obs.biglm <- function(x, ...) {
   x$n
 }
 
-#' @export
-nobs.biglm <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -143,11 +110,6 @@ n_obs.bigglm <- function(x, ...) {
   x$n
 }
 
-#' @export
-nobs.bigglm <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -155,11 +117,6 @@ n_obs.gbm <- function(x, ...) {
   length(x$fit)
 }
 
-#' @export
-nobs.gbm <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -167,11 +124,6 @@ n_obs.glimML <- function(x, ...) {
   nrow(x@data)
 }
 
-#' @export
-nobs.glimML <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -179,11 +131,6 @@ n_obs.glmRob <- function(x, ...) {
   length(x$fitted.values)
 }
 
-#' @export
-nobs.glmRob <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -191,12 +138,6 @@ n_obs.gmnl <- function(x, ...) {
   x$logLik$nobs
 }
 
-#' @export
-nobs.gmnl <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -204,11 +145,6 @@ n_obs.multinom <- function(x, ...) {
   nrow(x$fitted.values)
 }
 
-#' @export
-nobs.multinom <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -216,11 +152,6 @@ n_obs.rq <- function(x, ...) {
   length(x$fitted.values)
 }
 
-#' @export
-nobs.rq <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -228,12 +159,6 @@ n_obs.BBreg <- function(x, ...) {
   x$nObs
 }
 
-#' @export
-nobs.BBreg <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -241,12 +166,6 @@ n_obs.BBmm <- function(x, ...) {
   x$nObs
 }
 
-#' @export
-nobs.BBmm <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -258,10 +177,6 @@ n_obs.crq <- function(x, ...) {
   n
 }
 
-#' @export
-nobs.crq <- function(object, ...) {
-  n_obs(object, ...)
-}
 
 
 #' @importFrom stats fitted
@@ -270,11 +185,6 @@ n_obs.nlrq <- function(x, ...) {
   length(stats::fitted(x))
 }
 
-#' @export
-nobs.nlrq <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -282,38 +192,27 @@ n_obs.survfit <- function(x, ...) {
   length(x$n.event)
 }
 
-#' @export
-nobs.survfit <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
 n_obs.survreg <- function(x, ...) {
-  length(x$y)
+  length(x$linear.predictors)
 }
 
+
+
 #' @export
-nobs.survreg <- function(object, ...) {
-  n_obs(object, ...)
+n_obs.aareg <- function(x, ...) {
+  max(x$n)
 }
 
 
 
-
 #' @export
 n_obs.coxph <- function(x, ...) {
   max(x$n)
 }
 
-#' @export
-nobs.coxph <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -321,12 +220,6 @@ n_obs.coxme <- function(x, ...) {
   max(x$n)
 }
 
-#' @export
-nobs.coxme <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -334,12 +227,6 @@ n_obs.felm <- function(x, ...) {
   x$N
 }
 
-#' @export
-nobs.felm <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -347,11 +234,6 @@ n_obs.feis <- function(x, ...) {
   length(x$fitted.values)
 }
 
-#' @export
-nobs.feis <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -359,11 +241,6 @@ n_obs.aovlist <- function(x, ...) {
   nrow(stats::model.frame(x))
 }
 
-#' @export
-nobs.aovlist <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @rdname n_obs
@@ -382,12 +259,6 @@ n_obs.stanmvreg <- function(x, select = NULL, ...) {
   n
 }
 
-#' @export
-nobs.stanmvreg <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -395,12 +266,6 @@ n_obs.mlogit <- function(x, ...) {
   nrow(x$model)
 }
 
-#' @export
-nobs.mlogit <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -408,11 +273,6 @@ n_obs.hurdle <- function(x, ...) {
   x$n
 }
 
-#' @export
-nobs.hurdle <- function(object, ...) {
-  n_obs(object, ...)
-}
-
 
 
 #' @export
@@ -420,12 +280,6 @@ n_obs.zerotrunc <- function(x, ...) {
   x$n
 }
 
-#' @export
-nobs.zerotrunc <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
@@ -433,15 +287,16 @@ n_obs.zeroinfl <- function(x, ...) {
   x$n
 }
 
-#' @export
-nobs.zeroinfl <- function(object, ...) {
-  n_obs(object, ...)
-}
-
-
 
 
 #' @export
 n_obs.wbm <- function(x, ...) {
   nrow(x@frame)
 }
+
+
+
+#' @export
+n_obs.wbgee <- function(x, ...) {
+  stats::nobs(x)
+}
