@@ -108,7 +108,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 12)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c(
         "(Intercept)",
         "batch1",
