@@ -100,7 +100,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "sin(2 * pi * Time)", "cos(2 * pi * Time)")
     )
   })
